@@ -4,6 +4,7 @@
 #include <QMainWindow>
 #include <QFontDatabase>
 #include <QSettings>
+#include <QLabel>
 
 namespace Ui {
     class MainWindow;
@@ -24,9 +25,12 @@ private:
     QFontDatabase qfd;
     void notify(QString msg);
     QSettings settings;
+    void populateScroller(bool vis);
+    bool editmode;
+    QList<QLabel*> labellist;
 private slots:
     void toggleEditMode();
-    void updateScrollFontSizes(int val);
+    void updateScrollFontSizes(qreal val);
     void boldify(bool bold);
     void italicize(bool italic);
     void setSlider(int val);
